import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { AbstractService, httpOptions } from './abstract.service';
import { Base } from '../../../../../shared/common/model/base.model';

export abstract class AbstractRestService<T extends Base> extends AbstractService<T> {
  public constructor(httpClient: HttpClient, apiEntryPoint: string) {
    super(httpClient, apiEntryPoint);
  }

  public getAll(): Observable<T[]> {
    return this.httpClient.get<T[]>(this.apiEntryPoint);
  }

  public get(id: string | number): Observable<T> {
    return this.httpClient.get<T>(this.apiEntryPoint + `/${id}`, httpOptions);
  }

  public save(model: T): Observable<T> {
    return model.id ? this.update(model) : this.add(model);
  }

  public add(model: T): Observable<T> {
    return this.httpClient.put<T>(
      this.apiEntryPoint,
      JSON.stringify(model),
      httpOptions
    );
  }

  public update(model: T): Observable<T> {
    if (!model.id) {
      throwError('id of model is not valid');
    }
    return this.httpClient.post<T>(
      `${this.apiEntryPoint}`,
      JSON.stringify(model),
      httpOptions
    );
  }

  public delete(id: string | number): Observable<T> {
    return this.httpClient.delete<T>(
      `${this.apiEntryPoint}/${id}`,
      httpOptions
    );
  }
}
